==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_oc_prv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_prv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'ren qu’ais articles futurs (ges d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'ais articles totei sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totei leis articles, levat lei que son forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (leis utilizaires se devon abonar en donant son adreiça e-mail avans de poder mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (lei
 contribucions apareisson en public ren que se leis administrators
 leis an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat amb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar lei messatges sus lo còp
 (lei contribucions apareisson tre mandadas, leis administrators lei pòdon
 suprimir puei).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pus accedir a aquelei forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu tenir aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu tenir aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aquest forum es moderat a priòri: vòstra contribucion pareisserà ren qu’après qu’un administrator dau sit l’aga validada.', # MODIF
	'forum_lien_hyper' => '<b>Liame ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu: mandar au sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp lòng. La longor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mai per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(Se vòstre messatge se referís a un article publicat per lo web, o a una pagina que baile mai d’informacions, podètz marcar çai sota lo títol de la pagina e son adreiça.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fa seguida a vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Quau siatz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausida',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d’en primier vos cau registrar. Grandmercé
  de marcar çai sota l’identificant personau qu’avètz recebut.
 Se siatz pas registrat/ada, avètz de',
	'forum_vous_inscrire' => 'vos inscriure.',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir lei forums',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar lei forums publics, vougatz chausir son mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dei forums publics. Lei forums publics poiràn èsser autorizats au cas per cas subre leis articles; seràn proïbits subre lei rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís dei forums ais autors deis articles',
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dei forums</i> es una aisina de gestion dau vòstre sit (mai es pas un espaci per discutir o per redigir). Aficha totei lei contribucions dau forum public d’aquel article e vos permet de gerir aquelei contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei forums publics',
	'info_option_email' => 'Quora un vesitaire dau sit manda un messatge nòu au forum
 associat a un article, se’n pòt avisar leis autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Ges de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum deis administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum deis administrators',

	// L
	'lien_reponse_article' => 'Respònsa a l’article',
	'lien_reponse_breve_2' => 'Respònsa a la brèva',
	'lien_reponse_rubrique' => 'Respònsa a la rubrica',
	'lien_reponse_site_reference' => 'Respònsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sens tèxt',

	// R
	'repondre_message' => 'Respòndre a aqueu messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat deis administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit dei forums',
	'titre_page_forum_suivi' => 'Seguit dei forums'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_prv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_prv
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'ren qu’ais articles futurs (ges d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'ais articles totei sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totei leis articles, levat lei que son forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (leis utilizaires se devon abonar en donant son adreiça e-mail avans de poder mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (lei
 contribucions apareisson en public ren que se leis administrators
 leis an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat amb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar lei messatges sus lo còp
 (lei contribucions apareisson tre mandadas, leis administrators lei pòdon
 suprimir puei).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pus accedir a aquelei forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu tenir aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu tenir aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aquest forum es moderat a priòri: vòstra contribucion pareisserà ren qu’après qu’un administrator dau sit l’aga validada.', # MODIF
	'forum_lien_hyper' => '<b>Liame ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu: mandar au sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp lòng. La longor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mai per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(Se vòstre messatge se referís a un article publicat per lo web, o a una pagina que baile mai d’informacions, podètz marcar çai sota lo títol de la pagina e son adreiça.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fa seguida a vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Quau siatz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausida',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aqueu forum, d’en primier vos cau registrar. Grandmercé
  de marcar çai sota l’identificant personau qu’avètz recebut.
 Se siatz pas registrat/ada, avètz de',
	'forum_vous_inscrire' => 'vos inscriure.',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir lei forums',
	'icone_supprimer_message' => 'Suprimir aqueu messatge',
	'icone_valider_message' => 'Validar aqueu messatge',
	'info_activer_forum_public' => '<i>Per activar lei forums publics, vougatz chausir son mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dei forums publics. Lei forums publics poiràn èsser autorizats au cas per cas subre leis articles; seràn proïbits subre lei rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís dei forums ais autors deis articles',
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dei forums</i> es una aisina de gestion dau vòstre sit (mai es pas un espaci per discutir o per redigir). Aficha totei lei contribucions dau forum public d’aquel article e vos permet de gerir aquelei contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei forums publics',
	'info_option_email' => 'Quora un vesitaire dau sit manda un messatge nòu au forum
 associat a un article, se’n pòt avisar leis autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Ges de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum deis administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum deis administrators',

	// L
	'lien_reponse_article' => 'Respònsa a l’article',
	'lien_reponse_breve_2' => 'Respònsa a la brèva',
	'lien_reponse_rubrique' => 'Respònsa a la rubrica',
	'lien_reponse_site_reference' => 'Respònsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sens tèxt',

	// R
	'repondre_message' => 'Respòndre a aqueu messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat deis administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit dei forums',
	'titre_page_forum_suivi' => 'Seguit dei forums',
];
